#### Exerccios 7b. 
#### Uma estimativa da incerteza na previso do modelo

#Lendo o arquivo
babies = read.table("babies.txt", sep=" ", header=T, as.is=T)
#Verificando o objeto criado
babies
str(babies)
summary(babies)
#Transformando os valores ignorados em NA
babies$bwt[babies$bwt==999] = NA
babies$gestation[babies$gestation==999] = NA
babies$parity[babies$parity==9] = NA
babies$age[babies$age==99] = NA
babies$height[babies$height==99] = NA
babies$weight[babies$weight==999] = NA
babies$smoke[babies$smoke==9] = NA
#Transformando algumas variveis em fator
babies$parity = as.factor(babies$parity)
babies$smoke = as.factor(babies$smoke)
#Removendo dados faltantes para no termos problemas futuros
babies = na.omit(babies)
#Criando o modelo
model1 = lm(bwt ~ gestation, data=babies)
summary(model1)
model1.anova = anova(model1)
#Definindo parmetros e construindo o grfico
par(mar=c(5,5,4,2), bty="l", las=1, cex.lab=1.7, 
    family="serif", pch=19, cex=1.1, col=rgb(0,0,0,0.3),
    tcl=-0.3, mgp=c(3,0.5,0), cex.axis=1.3)
plot(bwt ~ gestation, data=babies, ylab="Weight at birth (oz)", 
     xlab="Gestation time (days)")
#Clculo do erro padro
SSX = anova(model1)$`Sum Sq`[2] 
s2 = var(babies$bwt) 
n = nrow(babies) 
x = seq(min(babies$gestation),max(babies$gestation), length.out=100) 
xm = mean(babies$gestation) 
se.babies = sqrt(s2*((1/n)+(((x-xm)^2)/SSX)))
#Clculo do intervalo de confiana
t = qt(0.025, n-2)
CI.babies = se.babies*t
#Construindo as retas
abline(model1, col=rgb(1,0,0, 1), lwd=2)
CI.coef = coef(model1)[1] + coef(model1)[2]*x
CI.coef
upper = CI.coef + CI.babies
lower = CI.coef - CI.babies
polygon(c(rev(x),x), c(rev(upper),lower), col=rgb(1,0,0, 0.1), border=NA)

#### Galileu estava Certo?
#Avalie se um polinmio de terceiro grau  um melhor modelo para descrever os dados do experimento de Galileu
#Recuperando os dados segundo o tutorial
init.h = c(600, 700, 800, 950, 1100, 1300, 1500)
h.d = c(253, 337, 395, 451, 495, 534, 573)
mod1 = lm(h.d~init.h)
mod2 = update(mod1,.~. +I(init.h^2))
#Criando o terceiro modelo
mod3 = update(mod2,.~. +I(init.h^3))
#Comparando modelos
anova(mod2, mod3)
#Com a anlise desses dois modelos, conclu-se que o modelo polinomial explica melhor os dados de Galileu.
#Sendo assim, enquanto Galileu estava certo em acreditar no ser uma relao linear, 
#ele estava errado em acreditar ser uma relao parablica (quadrtica).

#### Massa de Recm-Nascidos
#Utilize todas as variveis disponveis no conjunto de dados Massa ao Nascer e Dados da me para chegar ao melhor modelo de previso da massa de bebs ao nascer.
#Preparando os dados, conforme feito no primeiro exerccio:
babies = read.table("babies.txt", sep=" ", header=T, as.is=T)
babies$bwt[babies$bwt==999] = NA
babies$gestation[babies$gestation==999] = NA
babies$parity[babies$parity==9] = NA
babies$age[babies$age==99] = NA
babies$height[babies$height==99] = NA
babies$weight[babies$weight==999] = NA
babies$smoke[babies$smoke==9] = NA
babies$parity = as.factor(babies$parity)
babies$smoke = as.factor(babies$smoke)
babies = na.omit(babies)
str(babies)
#Construindo o modelo cheio
modelFull = lm(bwt ~ gestation*parity*age*height*weight*smoke, data=babies)
modelFull
anova(modelFull)
#Analisando o modelo cheio, vemos que nenhuma das interaes 3 a 3 so significativas para p = 0.05:
model2a2 =  lm(bwt ~ gestation*parity + gestation*age + gestation*height + gestation*weight + gestation*smoke +
                     parity*age + parity*height + parity*weight + parity*smoke +
                     age*height + age*weight + age*smoke +
                     height*weight + height*smoke +
                     weight*smoke, data=babies)
anova(model2a2)
anova(model2a2, modelFull)
#Podemos remover ainda mais interaes:
model3 = lm(bwt ~ gestation*parity + gestation*age + gestation*height + gestation*weight + gestation*smoke, data=babies)
anova(model3)
anova(model3, model2a2)
#Melhorando ainda mais:
model4 = lm(bwt ~ gestation + parity + age + height + weight + smoke + gestation:age + gestation:weight + gestation:smoke, data=babies)
anova(model4)
anova(model4, model3)
#E mais:
model5 = lm(bwt ~ gestation + parity + age + height + weight + smoke + gestation:age + gestation:smoke, data=babies)
anova(model5)
anova(model5, model4)
#Mais: 
model6 = lm(bwt ~ gestation + parity + height + weight + smoke + gestation:age + gestation:smoke, data=babies)    #Removendo "age"
anova(model6)
anova(model6, model5)
#Opa, removendo "age" o modelo se torna pior! Isto , explica uma frao menor dos resultados.
#Vejamos o que acontece para remoo da interao "gestation:age" e para a remoo de ambos os parmetros:
model7 = lm(bwt ~ gestation + parity + age + height + weight + smoke + gestation:smoke, data=babies)              #Removendo "gestation:age"
model8 = lm(bwt ~ gestation + parity + height + weight + gestation:smoke, data=babies)                            #Removendo ambos
anova(model7)
anova(model8)
anova(model7, model5)
anova(model8, model5)
#Os modelos tambm so piores!
#Embora o parmetro "age" no tenha um p significativo no model5, quando o tiramos (model6), obtemos um modelo pior, i.e., que explica uma porcentagem menor dos resultados.
#O mesmo acontece caso removamos a interao "gestation:age" (model7), ou ambos os parmetros (model8). Ou seja, o modelo 5, contendo os parmetros: gestation,
#parity, age, height, weight, smoke, gestation:age e gestation:smoke, se mostrou o melhor modelo para explicar os dados.